@@ -11,7 +11,7 @@ use Pinto::Util qw(is_remote_repo);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -38,6 +38,11 @@ sub pinto {
         $global_options->{root} ||= $ENV{PINTO_REPOSITORY_ROOT}
             || $self->usage_error('Must specify a repository root');
 
+        # Discard password and username arguments if this is not a 
+        # remote repository.  StrictConstrutor will not allow them.
+        delete @{$global_options}{qw(username password)}
+            if not is_remote_repo($global_options->{root});
+
         $global_options->{password} = $self->_prompt_for_password
             if defined $global_options->{password} and $global_options->{password} eq '-';
 
@@ -89,7 +94,7 @@ App::Pinto - Command-line driver for Pinto
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 SYNOPSIS
 
