@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.096'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -21,12 +21,14 @@ sub opt_spec {
     return (
         [ 'author=s'                          => 'The ID of the archive author' ],
         [ 'cascade'                           => 'Always pick latest upstream package' ],
+        [ 'diff-style=s'                      => 'Set style of diff reports' ],
         [ 'dry-run'                           => 'Do not commit any changes' ],
         [ 'message|m=s'                       => 'Message to describe the change' ],
         [ 'no-fail'                           => 'Do not fail when there is an error' ],
         [ 'no-index|x=s@'                     => 'Do not index matching packages' ],
         [ 'recurse!'                          => 'Recursively pull prereqs (negatable)' ],
         [ 'pin'                               => 'Pin packages to the stack' ],
+        [ 'skip-prerequisite|k:s@'            => 'Skip unsatisfiable prereqs (repeatable)' ],
         [ 'stack|s=s'                         => 'Put packages into this stack' ],
         [ 'use-default-message|M'             => 'Use the generated message' ],
         [ 'with-development-prerequisites|wd' => 'Also pull prereqs for development' ],
@@ -53,8 +55,8 @@ __END__
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
 G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
@@ -62,7 +64,7 @@ App::Pinto::Command::add - add local archives to the repository
 
 =head1 VERSION
 
-version 0.096
+version 0.098
 
 =head1 SYNOPSIS
 
@@ -111,10 +113,23 @@ that is found.  Remember that Pinto only searches the upstream
 repositories when the local repository does not already contain a
 satisfactory version of the package.
 
+=item --diff-style=STYLE
+
+Controls the style of the diff reports.  STYLE must be either C<concise> or
+C<detailed>.  Concise reports show only one record for each distribution added
+or deleted.  Detailed reports show one record for every package added or
+deleted.
+
+The default style is C<concise>.  However, the default style can changed by
+setting the C<PINTO_DIFF_STYLE> environment variable to your preferred STYLE.
+This variable affects the default style for diff reports generated by all
+other commands too.
+
 =item --dry-run
 
-Go through all the motions, but do not actually commit any changes to
-the repository.  Use this option to see how the command would
+Go through all the motions, but do not actually commit any changes to the
+repository.  At the conclusion, a diff showing the changes that would have 
+been made will be displayed.  Use this option to see how upgrades would 
 potentially impact the stack.
 
 =item --message=TEXT
@@ -167,6 +182,14 @@ index exactly as PAUSE would.  When using a PATTERN, take care to use a
 conservative one so you don't exclude the wrong packages.  Pinto will throw an
 exception if you exclude every package in the distribution.
 
+=item --pin
+
+Pins all the packages in the added distributions to the stack, so they
+cannot be changed until you unpin them.  The pin does not apply to any
+prerequisites that are pulled in for this distribution.  However, you
+may pin them separately with the
+L<pin|App::Pinto::Command::pin> command, if you so desire.
+
 =item --recurse
 
 =item --no-recurse
@@ -176,13 +199,17 @@ for the targets.  The default value for this option can be configured
 in the F<pinto.ini> configuration file for the repository (it is usually
 set to 1).  To disable recursion, use C<--no-recurse>.
 
-=item --pin
+=item --skip-prerequisite[=PACKAGE]
 
-Pins all the packages in the added distributions to the stack, so they
-cannot be changed until you unpin them.  The pin does not apply to any
-prerequisites that are pulled in for this distribution.  However, you
-may pin them separately with the
-L<pin|App::Pinto::Command::pin> command, if you so desire.
+=item -k[=PACKAGE]
+
+!! THIS OPTION IS EXPERIMENTAL !!
+
+Skip any prerequisite with name PACKAGE if it can't be satisfied.  However, a
+warning will be given whenever this occurrs.  If PACKAGE is not specified,
+then all unsatisfiable prerequisites wil be skipeed. This option only has
+effect when recursively fetching prerequisites for the targets (See also the
+C<--recurse> option). This option can be repeated.
 
 =item --stack NAME
 
