@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.096'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -22,11 +22,12 @@ sub opt_spec {
         [ 'cascade'                 => 'Always pick latest upstream package' ],
         [ 'cpanm-exe|cpanm=s'       => 'Path to the cpanm executable' ],
         [ 'cpanm-options|o:s%'      => 'name=value pairs of cpanm options' ],
+        [ 'diff-style=s'            => 'Set style of diff reports' ],
         [ 'local-lib|l=s'           => 'install into a local lib directory' ],
         [ 'local-lib-contained|L=s' => 'install into a contained local lib directory' ],
         [ 'message|m=s'             => 'Message to describe the change' ],
         [ 'do-pull'                 => 'pull missing prereqs onto the stack first' ],
-        [ 'stack|s=s'               => 'Use the index for this stack' ],
+        [ 'stack|s=s'               => 'Install modules from this stack' ],
 
     );
 }
@@ -67,10 +68,7 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
-G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn exe cpanm
+=for :stopwords Jeffrey Ryan Thalhammer exe cpanm
 
 =head1 NAME
 
@@ -78,7 +76,7 @@ App::Pinto::Command::install - install stuff from the repository
 
 =head1 VERSION
 
-version 0.096
+version 0.098
 
 =head1 SYNOPSIS
 
@@ -102,7 +100,7 @@ proceed.
 =head1 COMMAND ARGUMENTS
 
 Arguments are the things you want to install.  These can be package
-names, distribution paths, URLs, local files, or directories.  Look at
+names, distribution paths, URIs, local files, or directories.  Look at
 the L<cpanm> documentation to see all the different ways of specifying
 what to install.
 
@@ -118,14 +116,12 @@ or ';') will be ignored.
 
 !! THIS OPTION IS EXPERIMENTAL !!
 
-This option only matters when the C<--do-pull> option is also used.
-
-When searching for a prerequisite package, always take the latest 
-satisfactory version of the package found amongst B<all> the upstream 
-repositories, rather than just taking the B<first> satisfactory version 
-that is found.  Remember that Pinto only searches the upstream
-repositories when the local repository does not already contain a
-satisfactory version of the package.
+When searching for a prerequisite package, always take the latest
+satisfactory version of the package found amongst B<all> the upstream
+repositories, rather than just taking the B<first> satisfactory version that
+is found.  Remember that Pinto only searches the upstream repositories when
+the local repository does not already contain a satisfactory version of the
+package. This option only matters when the C<--do-pull> option is also used.
 
 =item --cpanm-exe PATH
 
@@ -144,21 +140,33 @@ the option NAME with a '-'.  You can pass any option you like, but the
 C<--mirror> and C<--mirror-only> options will always be set to point
 to the Pinto repository.
 
-=item --dry-run
+=item --diff-style=STYLE
 
-Go through all the motions, but do not actually commit any changes to
-the repository.  Use this option to see how the command would
-potentially impact the stack.  This only has effect when using the
-C<--pull> option.
+Controls the style of the diff reports.  STYLE must be either C<concise> or
+C<detailed>.  Concise reports show only one record for each distribution added
+or deleted.  Detailed reports show one record for every package added or
+deleted.  This option ony matters when the C<--do-pull> option is also used.
 
-=item --local-lib DIRECTORY
+The default style is C<concise>.  However, the default style can changed by
+setting the C<PINTO_DIFF_STYLE> environment variable to your preferred STYLE.
+This variable affects the default style for diff reports generated by all
+other commands too.
+
+=item --do-pull
+
+Pull the targets and recursively pull all their prerequisites onto the stack
+before installing.  Without the C<--do-pull> option, all targets and their
+prerequisites must already be on the stack or the installation will probably
+fail.  When the C<--do-pull> option is used, the stack must not be locked.
+
+=item --local-lib=DIRECTORY
 
 =item -l DIRECTORY
 
 Shortcut for setting the C<--local-lib> option on L<cpanm>.  Same as
 C<--cpanm-options local-lib=DIRECTORY> or C<-o l=DIRECTORY>.
 
-=item --local-lib-contained DIRECTORY
+=item --local-lib-contained=DIRECTORY
 
 =item -L DIRECTORY
 
@@ -178,14 +186,6 @@ control which editor is used.  A log message is not required whenever
 the C<--dry-run> option is set, or if the action did not yield any
 changes to the repository.
 
-=item --do-pull
-
-Pull the targets and recursively pull all their prerequisites onto the 
-stack before installing.  Without the C<--do-pull> option, all
-targets and their prerequisites must already be on the stack or the 
-installation will probably fail.  When the C<--do-pull> option is
-used, the stack must not be locked.
-
 =item --stack=NAME
 
 =item -s NAME
@@ -201,10 +201,10 @@ the repository.
 
 =head1 USING cpan OR cpanm DIRECTLY
 
-On the surface, A Pinto repository looks like an ordinary CPAN repository,
-so you can use any client to install modules.  All you have to do is "point" 
-it at the URL of your Pinto repository.  Each client has a slightly different 
-interface for setting the URL.
+On the surface, A Pinto repository looks like an ordinary CPAN repository, so
+you can use any client to install modules.  All you have to do is "point"  it
+at the URI of your Pinto repository.  Each client has a slightly different
+interface for setting the URI.
 
 For L<cpanm>, use the C<--mirror> and C<--mirror-only> options like this:
 
@@ -218,24 +218,23 @@ For L<cpan>, set the C<urllist> config option via the shell like this:
   cpan[3]> install Some::Package
   cpan[4]> o conf commit     # If you want to make the change permanent
 
-Pointing your client at the top of your repository will install modules
-from the default stack.  To install from a particular stack, just add it 
-to the URL.  For example:
+Pointing your client at the top of your repository will install modules from
+the default stack.  To install from a particular stack, just append the stack
+name to the URI.  For example:
 
   file:///path/to/repo                # Install from default stack
   file:///path/to/repo/stacks/dev     # Install from "dev" stack
   file:///path/to/repo/stacks/prod    # Install from "prod" stack
 
 If your repository does not have a default stack then you must specify the
-full URL to one of the stacks as shown above.
+full URI to one of the stacks as shown above.
 
 =head1 COMPATIBILITY
 
-The C<install> does not support some of the newer features found in
-version 1.6 (or later) of L<cpanm>, such as installing from a Git 
-repository, installing development releases, or using complex version 
-expressions. If you pass any of those as arguments to this command, the 
-behavior is unspecified.
+The C<install> command does not support some of the newer features found in
+version 1.6 (or later) of L<cpanm>, such as installing from a Git repository,
+installing development releases, or using complex version  expressions. If you
+pass any of those as arguments to this command, the behavior is unspecified.
 
 =head1 AUTHOR
 
