@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -22,7 +22,11 @@ sub command_names { return qw(log history) }
 sub opt_spec {
     my ( $self, $app ) = @_;
 
-    return ( [ 'stack|s=s' => 'Show history for this stack' ], );
+    return ( 
+    	[ 'stack|s=s'    => 'Show history for this stack'  ],
+      [ 'with-diffs|d' => 'Show a diff for each revision'], 
+      [ 'diff-style=s' => 'Diff style (concise|detailed)' ],
+    );
 }
 
 #------------------------------------------------------------------------------
@@ -49,8 +53,8 @@ __END__
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
 G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
@@ -58,7 +62,7 @@ App::Pinto::Command::log - show the revision logs of a stack
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 SYNOPSIS
 
@@ -68,9 +72,7 @@ version 0.097
 
 !! THIS COMMAND IS EXPERIMENTAL !!
 
-This command shows the commit logs for the stack.  To see the precise
-changes in any particular commit, use the L<App::Pinto::Command::show>
-command.
+This command shows the revision logs for the stack.
 
 =head1 COMMAND ARGUMENTS
 
@@ -89,6 +91,14 @@ be shown.
 
 =over 4
 
+=item --with-diffs
+
+=item -d
+
+For each revision, also show the diff from the previous revision.
+If the C<PINTO_DETAILED_DIFF> environment varaible is set to a 
+true value, a detailed diff will be shown.
+
 =item --stack NAME
 
 =item -s NAME
