@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.096'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -19,6 +19,7 @@ sub opt_spec {
     my ( $self, $app ) = @_;
 
     return (
+        [ 'diff-style=s'          => 'Set style of diff reports' ],
         [ 'dry-run'               => 'Do not commit any changes' ],
         [ 'force'                 => 'Remove packages even if pinned' ],
         [ 'message|m=s'           => 'Message to describe the change' ],
@@ -46,8 +47,8 @@ __END__
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
 G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
@@ -55,7 +56,7 @@ App::Pinto::Command::unregister - remove packages from a stack
 
 =head1 VERSION
 
-version 0.096
+version 0.098
 
 =head1 SYNOPSIS
 
@@ -92,6 +93,18 @@ or ';') will be ignored.
 
 =over 4
 
+=item --diff-style=STYLE
+
+Controls the style of the diff reports.  STYLE must be either C<concise> or
+C<detailed>.  Concise reports show only one record for each distribution added
+or deleted.  Detailed reports show one record for every package added or
+deleted.
+
+The default style is C<concise>.  However, the default style can changed by
+setting the C<PINTO_DIFF_STYLE> environment variable to your preferred STYLE.
+This variable affects the default style for diff reports generated by all
+other commands too.
+
 =item --dry-run
 
 Go through all the motions, but do not actually commit any changes to
