@@ -8,11 +8,11 @@ use MooseX::Types::Moose qw(Bool);
 use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Pinto::Util qw(throw);
-use Pinto::Types qw(DistSpecList);
+use Pinto::Types qw(DistributionTargetList);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -25,7 +25,7 @@ with qw( Pinto::Role::Transactional );
 #------------------------------------------------------------------------------
 
 has targets => (
-    isa      => DistSpecList,
+    isa      => DistributionTargetList,
     traits   => [qw(Array)],
     handles  => { targets => 'elements' },
     required => 1,
@@ -45,7 +45,7 @@ sub execute {
 
     for my $target ( $self->targets ) {
 
-        my $dist = $self->repo->get_distribution( spec => $target );
+        my $dist = $self->repo->get_distribution( target => $target );
 
         throw "Distribution $target is not in the repository" if not defined $dist;
 
@@ -79,7 +79,7 @@ Pinto::Action::Delete - Delete archives from the repository
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 AUTHOR
 
