@@ -1,19 +1,21 @@
-# ABSTRACT: Show the difference between two stacks
+# ABSTRACT: Show the difference between stacks or revisions
 
 package Pinto::Action::Diff;
 
 use Moose;
+use MooseX::Aliases;
 use MooseX::StrictConstructor;
 use MooseX::MarkAsMethods ( autoclean => 1 );
+use MooseX::Types::Moose qw(Bool);
 
 use Pinto::Difference;
-use Pinto::Constants qw(:color);
-use Pinto::Types qw(StackName StackDefault StackObject RevisionID);
-use Pinto::Util qw(throw);
+use Pinto::Constants qw(:color :diff);
+use Pinto::Types qw(StackName StackDefault StackObject RevisionID DiffStyle);
+use Pinto::Util qw(throw default_diff_style);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.096'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -23,7 +25,7 @@ extends qw( Pinto::Action );
 
 has left => (
     is      => 'ro',
-    isa     => StackName | StackDefault | StackObject | RevisionID,
+    isa     => StackName | StackObject | StackDefault | RevisionID,
     default => undef,
 );
 
@@ -33,6 +35,13 @@ has right => (
     required => 1,
 );
 
+has style => (
+    is       => 'ro',
+    isa      => DiffStyle,
+    alias    => 'diff_style',
+    default  => \&default_diff_style,
+);
+
 #------------------------------------------------------------------------------
 
 sub execute {
@@ -41,27 +50,34 @@ sub execute {
     my $error_message = qq{"%s" does not match any stack or revision};
 
     my $left =
-           $self->repo->get_stack( $self->left, ( nocroak => 1 ) )
+           $self->repo->get_stack_maybe( $self->left )
         || $self->repo->get_revision( $self->left )
         || throw sprintf $error_message, $self->left;
 
     my $right =
-           $self->repo->get_stack( $self->right, ( nocroak => 1 ) )
+           $self->repo->get_stack_maybe( $self->right )
         || $self->repo->get_revision( $self->right )
         || throw sprintf $error_message, $self->right;
 
-    my $diff = Pinto::Difference->new( left => $left, right => $right );
+    my $diff = Pinto::Difference->new( left  => $left, 
+                                       right => $right, 
+                                       style => $self->style );
+
+    # TODO: Extract the colorizing & formatting code into a separate
+    # class that can be reused.  Maybe subclassed for HTML and text.
 
     if ( $diff->is_different ) {
         $self->show( "--- $left",  { color => $PINTO_COLOR_1 } );
         $self->show( "+++ $right", { color => $PINTO_COLOR_1 } );
     }
 
-    for my $entry ( $diff->diffs ) {
-        my $op     = $entry->op;
-        my $reg    = $entry->registration;
-        my $color  = $op eq '+' ? $PINTO_COLOR_0 : $PINTO_COLOR_2;
-        my $string = $op . $reg->to_string('[%F] %-40p %12v %a/%f');
+    my $format = $self->style eq $PINTO_DIFF_STYLE_DETAILED 
+        ? '%o[%F] %-40p %12v %a/%f' 
+        : '%o[%F] %a/%f';
+
+    for my $entry ( $diff->entries ) {
+        my $color  = $entry->is_addition ? $PINTO_COLOR_0 : $PINTO_COLOR_2;
+        my $string = $entry->to_string($format);
         $self->show( $string, { color => $color } );
     }
 
@@ -84,16 +100,16 @@ __END__
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
 G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
-Pinto::Action::Diff - Show the difference between two stacks
+Pinto::Action::Diff - Show the difference between stacks or revisions
 
 =head1 VERSION
 
-version 0.096
+version 0.098
 
 =head1 AUTHOR
 
