@@ -4,16 +4,17 @@ package Pinto::Action::Log;
 
 use Moose;
 use MooseX::StrictConstructor;
-use MooseX::Types::Moose qw(Str);
+use MooseX::Types::Moose qw(Str Bool);
 use MooseX::MarkAsMethods ( autoclean => 1 );
 
+use Pinto::Difference;
 use Pinto::RevisionWalker;
 use Pinto::Constants qw(:color);
-use Pinto::Types qw(StackName StackDefault);
+use Pinto::Types qw(StackName StackDefault DiffStyle);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -27,12 +28,19 @@ has stack => (
     default => undef,
 );
 
-has format => (
+has with_diffs => (
     is        => 'ro',
-    isa       => Str,
-    predicate => 'has_format',
+    isa       => Bool,
+    default   => 0,
 );
 
+has diff_style => (
+    is        => 'ro',
+    isa       => DiffStyle,
+    predicate => 'has_diff_style',
+);
+
+
 #------------------------------------------------------------------------------
 
 sub execute {
@@ -48,6 +56,13 @@ sub execute {
 
         my $rest = $revision->to_string("Date: %u\nUser: %j\n\n%{4}G\n");
         $self->show($rest);
+
+        if ($self->with_diffs) {
+            my $parent = ($revision->parents)[0];
+            local $ENV{PINTO_DIFF_STYLE} = $self->diff_style if $self->has_diff_style;
+            my $diff = Pinto::Difference->new(left => $parent, right => $revision);
+            $self->show($diff);
+        }
     }
 
     return $self->result;
@@ -75,7 +90,7 @@ Pinto::Action::Log - Show revision log for a stack
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 AUTHOR
 
