@@ -12,7 +12,7 @@ use Pinto::Types qw(StackName StackDefault StackObject);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -39,29 +39,11 @@ sub execute {
     my ($self) = @_;
 
     my $stack = $self->repo->get_stack($self->stack);
-    my @dists = $stack->head->distributions->all;
-    my %is_prereq_dist;
-    my %cache;
-
-    # Algorithm: Visit each distribution and resolve each of its
-    # dependencies to the prerequisite distribution (if it exists).
-    # Any distribution that is a prerequisite cannot be a root.
-
-    for my $dist ( @dists ) {
-        next if $is_prereq_dist{$dist};
-        for my $prereq ($dist->prerequisites) {
-            my %args = (spec => $prereq->as_spec, cache => \%cache);
-            next unless my $prereq_dist = $stack->get_distribution(%args);
-            $is_prereq_dist{$prereq_dist}++;
-        }
-    }
-
-    my @roots  = grep { ! $is_prereq_dist{$_} } @dists;
-    my @output = sort map { $_->to_string($self->format) } @roots;
-    $self->show($_) for @output;
+    my @roots = sort map { $_->to_string($self->format) } $stack->roots;
+    $self->show($_) for @roots;
 
     return $self->result;
-} 
+}
 
 #------------------------------------------------------------------------------
 
@@ -85,7 +67,7 @@ Pinto::Action::Roots - Show the roots of a stack
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 AUTHOR
 
