@@ -7,13 +7,16 @@ use MooseX::StrictConstructor;
 use MooseX::Types::Moose qw(ArrayRef Bool);
 use MooseX::MarkAsMethods ( autoclean => 1 );
 
-use Pinto::Util qw(itis);
+use Pinto::DifferenceEntry;
+use Pinto::Constants qw(:diff);
+use Pinto::Types qw(DiffStyle);
+use Pinto::Util qw(itis default_diff_style);
 
 use overload ( q{""} => 'to_string' );
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -29,9 +32,9 @@ has right => (
     required => 1,
 );
 
-has diffs => (
+has entries => (
     traits   => [qw(Array)],
-    handles  => { diffs => 'elements' },
+    handles  => { entries => 'elements' },
     isa      => ArrayRef ['Pinto::DifferenceEntry'],
     builder  => '_build_diffs',
     init_arg => undef,
@@ -41,12 +44,8 @@ has diffs => (
 has additions => (
     traits  => [qw(Array)],
     handles => { additions => 'elements' },
-    isa     => ArrayRef ['Pinto::Schema::Result::Registration'],
-    default => sub {
-        [   map  { $_->registration }
-            grep { $_->op eq '+' } $_[0]->diffs
-        ];
-    },
+    isa     => ArrayRef ['Pinto::DifferenceEntry'],
+    default => sub { [ grep { $_->op eq '+' } shift->entries ] },
     init_arg => undef,
     lazy     => 1,
 );
@@ -54,12 +53,8 @@ has additions => (
 has deletions => (
     traits  => [qw(Array)],
     handles => { deletions => 'elements' },
-    isa     => ArrayRef ['Pinto::Schema::Result::Registration'],
-    default => sub {
-        [   map  { $_->registration }
-            grep { $_->op eq '-' } $_[0]->diffs
-        ];
-    },
+    isa     => ArrayRef ['Pinto::DifferenceEntry'],
+    default => sub { [ grep { $_->op eq '-' } shift->entries ] },
     init_arg => undef,
     lazy     => 1,
 );
@@ -68,10 +63,16 @@ has is_different => (
     is       => 'ro',
     isa      => Bool,
     init_arg => undef,
-    default  => sub { shift->diffs > 0 },
+    default  => sub { shift->entries > 0 },
     lazy     => 1,
 );
 
+has style => (
+    is       => 'ro',
+    isa      => DiffStyle,
+    default  => \&default_diff_style,
+);
+
 #------------------------------------------------------------------------------
 
 around BUILDARGS => sub {
@@ -100,9 +101,14 @@ sub _build_diffs {
     # side.  Two registrations are the same if they have the same values in
     # the package, distribution, and is_pinned columns.  So we use these
     # columns to construct the keys of a hash.  The value is the id of
-    # the registration.
+    # the registration.  For a concise diff, we just use the distribution
+    # and is_pinned columns, which effectively groups the records so there
+    # is only one diff entry per distribution.  In that case, the package
+    # referenced by the registration won't be meaningful.
 
-    my @fields = qw(distribution package is_pinned);
+    my @fields = $self->style eq $PINTO_DIFF_STYLE_DETAILED
+        ? qw(distribution package is_pinned)
+        : qw(distribution is_pinned);
 
     my $cb = sub {
         my $value = $_[0]->id;
@@ -119,8 +125,8 @@ sub _build_diffs {
     # present on the right but not on the left have been added.  And
     # those present on left but not on the right have been deleted.
 
-    my @add_ids = @right{ grep { not exists $left{$_} } keys %right };
-    my @del_ids = @left{ grep  { not exists $right{$_} } keys %left };
+    my @add_ids = @right{ grep { not exists $left{$_}  } keys %right };
+    my @del_ids = @left{  grep { not exists $right{$_} } keys %left };
 
     # Now we have the ids of all the registrations that were added or
     # deleted between the left and right revisions.  We use those ids to
@@ -133,7 +139,7 @@ sub _build_diffs {
     # the diff is more readable if we group registrations together by
     # distribution name.
 
-    my @diffs = sort @adds, @dels;
+    my @diffs = sort @dels, @adds;
 
     return \@diffs;
 }
@@ -160,7 +166,9 @@ sub _create_entries {
 
     my $where   = { 'me.id' => { in => \"SELECT reg from $tmp_tbl" } };
     my $reg_rs  = $side->registrations($where)->with_distribution->with_package;
-    my @entries = map { Pinto::DifferenceEntry->new( op => $type, registration => $_ ) } $reg_rs->all;
+
+    my @entries = map { Pinto::DifferenceEntry->new( op => $type,
+                                                     registration => $_ ) } $reg_rs->all;
 
     $dbh->do("DROP TABLE $tmp_tbl");
 
@@ -172,7 +180,7 @@ sub _create_entries {
 sub foreach {
     my ( $self, $cb ) = @_;
 
-    $cb->($_) for $self->diffs;
+    $cb->($_) for $self->entries;
 
     return $self;
 }
@@ -182,61 +190,11 @@ sub foreach {
 sub to_string {
     my ($self) = @_;
 
-    return join '', $self->diffs;
-}
+    my $format = $self->style eq $PINTO_DIFF_STYLE_CONCISE
+        ? '%o[%F] %a/%f'
+        : '';
 
-#------------------------------------------------------------------------------
-
-__PACKAGE__->meta->make_immutable;
-
-###############################################################################
-###############################################################################
-
-package Pinto::DifferenceEntry;
-
-use Moose;
-use MooseX::StrictConstructor;
-use MooseX::MarkAsMethods ( autoclean => 1 );
-use MooseX::Types::Moose qw(Str);
-
-use overload (
-    q{""} => 'to_string',
-    'cmp' => 'string_compare',
-);
-
-#------------------------------------------------------------------------------
-
-our $VERSION = '0.097'; # VERSION
-
-#------------------------------------------------------------------------------
-
-has op => (
-    is       => 'ro',
-    isa      => Str,
-    required => 1
-);
-
-has registration => (
-    is       => 'ro',
-    isa      => 'Pinto::Schema::Result::Registration',
-    required => 1,
-);
-
-#------------------------------------------------------------------------------
-
-sub to_string {
-    my ($self) = @_;
-
-    my $format = "[%F] %-40p %12v %a/%f\n";
-    return $self->op . $self->registration->to_string($format);
-}
-
-#------------------------------------------------------------------------------
-
-sub string_compare {
-    my ( $self, $other ) = @_;
-
-    return ( $self->registration->distribution->name cmp $other->registration->distribution->name );
+    return join("\n", map {$_->to_string($format) } $self->entries) . "\n";
 }
 
 #------------------------------------------------------------------------------
@@ -252,7 +210,10 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Jeffrey Ryan Thalhammer
+=for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
+G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
@@ -260,7 +221,7 @@ Pinto::Difference - Compute difference between two revisions
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 AUTHOR
 
