@@ -15,7 +15,7 @@ use Pinto::Util qw(debug throw);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -63,7 +63,7 @@ sub _write_header {
     my ( $self, $fh, $filename, $line_count ) = @_;
 
     my $base = $filename->basename;
-    my $url  = 'file://' . $filename->absolute->as_foreign('Unix');
+    my $uri  = 'file://' . $filename->absolute->as_foreign('Unix');
 
     my $writer  = ref $self;
     my $version = $self->VERSION || 'UNKNOWN';
@@ -71,7 +71,7 @@ sub _write_header {
 
     print {$fh} <<"END_PACKAGE_HEADER";
 File:         $base
-URL:          $url
+URL:          $uri
 Description:  Package names found in directory \$CPAN/authors/id/
 Columns:      package name, version, path
 Intended-For: Automated fetch routines, namespace documentation.
@@ -143,8 +143,8 @@ __END__
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
 G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
@@ -152,7 +152,7 @@ Pinto::IndexWriter - Write records to an 02packages.details.txt file
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 AUTHOR
 
