@@ -11,14 +11,14 @@ use URI;
 use URI::Escape;
 
 use Pinto::Types qw(Uri File);
-use Pinto::Util qw(throw debug);
+use Pinto::Util qw(throw);
 use Pinto::IndexReader;
 
 use version;
 
 #------------------------------------------------------------------------
 
-our $VERSION = '0.09992_02'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------
 
@@ -71,22 +71,11 @@ sub locate_package {
     my ($self, %args) = @_;
 
     my $target = $args{target};
-
+ 
     return unless my $found = $self->reader->packages->{$target->name};
     return unless $target->is_satisfied_by( $found->{version} );
 
-    # Indexes from a Pinto repository have fake records for core modules, so
-    # installers can decide if they need to update a dual-life module. If we
-    # get one of those fake records, then we pretend we didn't see it. So if
-    # we really do need a perl, some other upstream source will provide it.
-
-    if ( $found->{path} =~ m{^F/FA/FAKE/perl} ) {
-        my ($uri, $path) = ($self->uri, $found->{path});
-        debug "Skipping fake perl found on $uri at $path";
-        return;
-    }
-
-    $found = { %$found }; # Shallow clone
+    # Morph data structure to meet spec
     $found->{package} = delete $found->{name};
     $found->{uri} = URI->new($self->uri . "/authors/id/$found->{path}");
     $found->{version} = version->parse($found->{version});
@@ -102,7 +91,7 @@ sub locate_distribution {
 
     my $target = $args{target};
     my $path  = $target->path;
-
+    
     my @extensions = qw(tar.gz tar.bz2 tar gz tgz bz2 zip z);
     my $has_extension = $path =~ m/[.](?:tar|gz|tgz|zip|z|bz2)$/i;
     my @paths_to_try = $has_extension ? ($path) : map { "$path.$_" } @extensions;
@@ -147,7 +136,7 @@ Pinto::Locator::Mirror - The package index of a repository
 
 =head1 VERSION
 
-version 0.09992_02
+version 0.098
 
 =head1 AUTHOR
 
@@ -155,7 +144,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
