@@ -17,11 +17,11 @@ use Pinto::Types qw(Uri);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.096'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
-with qw(Pinto::Role::Plated);
+with qw(Pinto::Role::Plated Pinto::Role::UserAgent);
 
 #------------------------------------------------------------------------------
 
@@ -43,20 +43,6 @@ has password => (
     isa => Maybe [Str],
 );
 
-has ua => (
-    is      => 'ro',
-    isa     => 'LWP::UserAgent',
-    default => sub { LWP::UserAgent->new( agent => $_[0]->ua_name, env_proxy => 1 ) },
-    lazy    => 1,
-);
-
-has ua_name => (
-    is      => 'ro',
-    isa     => Str,
-    default => sub { sprintf '%s/%s', ref $_[0], $_[0]->VERSION || '??' },
-    lazy    => 1,
-);
-
 #------------------------------------------------------------------------------
 
 around BUILDARGS => sub {
@@ -98,7 +84,6 @@ sub run {
         username => $self->username,
         password => $self->password,
         chrome   => $self->chrome,
-        ua       => $self->ua
     );
 
     return $action->execute;
@@ -139,8 +124,8 @@ __END__
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
 G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
@@ -148,7 +133,7 @@ Pinto::Remote - Interact with a remote Pinto repository
 
 =head1 VERSION
 
-version 0.096
+version 0.098
 
 =head1 SYNOPSIS
 
@@ -167,7 +152,7 @@ on the remote host.
 
 If you are using the L<pinto> application, it will automatically load
 either Pinto or Pinto::Remote depending on whether your repository
-root looks like a local directory path or a remote URL.
+root looks like a local directory path or a remote URI.
 
 =head1 METHODS
 
