@@ -9,12 +9,12 @@ use MooseX::MarkAsMethods ( autoclean => 1 );
 use Path::Class qw(dir);
 use File::Which qw(which);
 
-use Pinto::Util qw(throw mask_url_passwords);
+use Pinto::Util qw(throw mask_uri_passwords);
 use Pinto::Constants qw($PINTO_MINIMUM_CPANM_VERSION);
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -34,7 +34,7 @@ has cpanm_exe => (
 
 #-----------------------------------------------------------------------------
 
-requires qw( execute targets mirror_url );
+requires qw( execute targets mirror_uri );
 
 #-----------------------------------------------------------------------------
 
@@ -72,7 +72,7 @@ after execute => sub {
 
     # Wire cpanm to our repo
     my $opts = $self->cpanm_options;
-    $opts->{mirror} = $self->mirror_url;
+    $opts->{mirror} = $self->mirror_uri;
     $opts->{'mirror-only'} = '';
 
     # Process other cpanm options
@@ -86,7 +86,7 @@ after execute => sub {
     }
 
     # Scrub passwords from the command so they don't appear in the logs
-    my @sanitized_cpanm_opts = map { mask_url_passwords($_) } @cpanm_opts;
+    my @sanitized_cpanm_opts = map { mask_uri_passwords($_) } @cpanm_opts;
     $self->info( join ' ', 'Running:', $self->cpanm_exe, @sanitized_cpanm_opts );
 
     # Run cpanm
@@ -105,8 +105,8 @@ __END__
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
 G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
@@ -114,7 +114,7 @@ Pinto::Role::Installer - Something that installs packages
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 AUTHOR
 
