@@ -13,11 +13,11 @@ use Pinto::Util qw(debug throw);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.097'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
-with qw( Pinto::Role::FileFetcher );
+with qw( Pinto::Role::UserAgent );
 
 #------------------------------------------------------------------------------
 
@@ -37,7 +37,7 @@ sub add_archive {
     throw "$origin does not exist" if not -e $origin;
     throw "$origin is not a file"  if not -f $origin;
 
-    $self->fetch( from => $origin, to => $destination );
+    $self->mirror( $origin => $destination );
     $self->update_checksums( directory => $destination->parent );
 
     return $self;
@@ -123,7 +123,7 @@ Pinto::Store - Storage for distribution archives
 
 =head1 VERSION
 
-version 0.097
+version 0.098
 
 =head1 DESCRIPTION
 
