@@ -10,7 +10,6 @@ use Try::Tiny;
 use Module::CoreList;
 use CPAN::Meta::Requirements;
 
-use Pinto::Types qw(Version);
 use Pinto::Util qw(throw trim_text);
 
 use version;
@@ -18,7 +17,7 @@ use overload ( '""' => 'to_string');
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.09992_02'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -30,9 +29,8 @@ has name => (
 
 has version => (
     is      => 'ro',
-    isa     => Str | Version,
+    isa     => Str,
     default => '0',
-    coerce  => 1,
 );
 
 has _vreq => (
@@ -131,14 +129,6 @@ sub is_satisfied_by {
 
 #-------------------------------------------------------------------------------
 
-sub unversioned {
-    my ($self) = @_;
-
-    return (ref $self)->new(name => $self->name);
-}
-
-#-------------------------------------------------------------------------------
-
 
 sub to_string {
     my ($self) = @_;
@@ -176,7 +166,7 @@ Pinto::Target::Package - Specifies a package by name and version
 
 =head1 VERSION
 
-version 0.09992_02
+version 0.098
 
 =head1 METHODS
 
@@ -207,7 +197,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
