@@ -6,13 +6,33 @@ use strict;
 use warnings;
 use version;
 
-use MooseX::Types -declare => [
-    qw( AuthorID Username Uri Dir File FileList Io Version
-        StackName StackAll StackDefault PropertyName PkgSpec
-        PkgSpecList StackObject DistSpec DistSpecList
-        Spec SpecList RevisionID RevisionHead
-        ANSIColor ANSIColorSet PerlVersion)
-];
+use MooseX::Types -declare => [ qw( 
+    ANSIColor 
+    ANSIColorSet 
+    AuthorID 
+    DiffStyle
+    Dir 
+    DistributionTarget
+    DistributionTargetList
+    File 
+    FileList 
+    Io 
+    PackageTarget
+    PackageTargetList
+    PerlVersion
+    PropertyName 
+    RevisionHead
+    RevisionID 
+    StackAll 
+    StackDefault 
+    StackName 
+    StackObject 
+    Target 
+    TargetList 
+    Uri 
+    Username 
+    Version
+)];
 
 use MooseX::Types::Moose qw( Str Num ScalarRef ArrayRef Undef
     HashRef FileHandle Object Int );
@@ -26,12 +46,12 @@ use IO::String;
 use IO::Handle;
 use IO::File;
 
-use Pinto::SpecFactory;
+use Pinto::Target;
 use Pinto::Constants qw(:all);
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.096'; # VERSION
+our $VERSION = '0.098'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -65,7 +85,8 @@ subtype StackDefault, as Undef;
 
 #-----------------------------------------------------------------------------
 
-class_type StackObject, { class => 'Pinto::Schema::Result::Stack' };
+class_type StackObject, 
+    { class => 'Pinto::Schema::Result::Stack' };
 
 #-----------------------------------------------------------------------------
 
@@ -75,11 +96,14 @@ subtype PropertyName, as Str,
 
 #-----------------------------------------------------------------------------
 
-class_type Version, { class => 'version' };
+class_type Version, 
+    { class => 'version' };
 
-coerce Version, from Str, via { version->parse($_) };
+coerce Version, 
+    from Str, via { version->parse($_) };
 
-coerce Version, from Num, via { version->parse($_) };
+coerce Version, 
+    from Num, via { version->parse($_) };
 
 #-----------------------------------------------------------------------------
 
@@ -87,9 +111,11 @@ subtype PerlVersion, as Object,
     where { $_->isa('version') && exists $Module::CoreList::version{ $_->numify + 0 } },
     message {"perl version ($_) is unknown to me"};
 
-coerce PerlVersion, from Str, via { version->parse($_) };
+coerce PerlVersion, 
+    from Str, via { version->parse($_) };
 
-coerce PerlVersion, from Num, via { version->parse($_) };
+coerce PerlVersion, 
+    from Num, via { version->parse($_) };
 
 #-----------------------------------------------------------------------------
 
@@ -99,85 +125,96 @@ subtype ANSIColor, as Str,
 
 #-----------------------------------------------------------------------------
 
-subtype ANSIColorSet, as ArrayRef [ANSIColor], where { @{$_} == 3 }, message {'Must be exactly three colors'};
+subtype ANSIColorSet, as ArrayRef[ANSIColor],
+    where { @{$_} == 3 },
+    message {'Must be exactly three colors'};
 
 #-----------------------------------------------------------------------------
 
-class_type Uri, { class => 'URI' };
+class_type Uri, 
+    { class => 'URI' };
 
-coerce Uri, from Str, via { URI->new($_) };
+coerce Uri, 
+    from Str, via { URI->new($_) };
 
 #-----------------------------------------------------------------------------
 
-class_type Dir, { class => 'Path::Class::Dir' };
+class_type Dir, 
+    { class => 'Path::Class::Dir' };
 
-coerce Dir, from Str, via { Path::Class::Dir->new($_) }, from ArrayRef, via { Path::Class::Dir->new( @{$_} ) };
+coerce Dir, 
+    from Str,      via { Path::Class::Dir->new($_) }, 
+    from ArrayRef, via { Path::Class::Dir->new( @{$_} ) };
 
 #-----------------------------------------------------------------------------
 
-class_type File, { class => 'Path::Class::File' };
+class_type File, 
+    { class => 'Path::Class::File' };
 
-coerce File, from Str, via { Path::Class::File->new($_) }, from ArrayRef, via { Path::Class::File->new( @{$_} ) };
+coerce File, 
+    from Str,      via { Path::Class::File->new($_) }, 
+    from ArrayRef, via { Path::Class::File->new( @{$_} ) };
 
 #-----------------------------------------------------------------------------
 
 subtype FileList, as ArrayRef [File];
 
-coerce FileList, from File, via { [$_] }, from Str, via { [ Path::Class::File->new($_) ] }, from ArrayRef [Str], via {
-    [ map { Path::Class::File->new($_) } @$_ ];
-};
+coerce FileList,
+    from File,          via { [ $_ ] }, 
+    from Str,           via { [ Path::Class::File->new($_) ] }, 
+    from ArrayRef[Str], via { [ map { Path::Class::File->new($_) } @$_ ] };
 
 #-----------------------------------------------------------------------------
 
-class_type PkgSpec, { class => 'Pinto::PackageSpec' };
+class_type PackageTarget, { class => 'Pinto::Target::Package' };
 
-coerce PkgSpec,
-    from Str,     via { Pinto::SpecFactory->make_spec($_) },
-    from HashRef, via { Pinto::SpecFactory->make_spec($_) };
+coerce PackageTarget,
+    from Str,     via { Pinto::Target->new($_) },
+    from HashRef, via { Pinto::Target->new($_) };
 
 #-----------------------------------------------------------------------------
 
-class_type DistSpec, { class => 'Pinto::DistributionSpec' };
+class_type DistributionTarget, { class => 'Pinto::Target::Distribution' };
 
-coerce DistSpec,
-    from Str,     via { Pinto::SpecFactory->make_spec($_) },
-    from HashRef, via { Pinto::SpecFactory->make_spec($_) };
+coerce DistributionTarget,
+    from Str,     via { Pinto::Target->new($_) },
+    from HashRef, via { Pinto::Target->new($_) };
 
 #-----------------------------------------------------------------------------
 
-subtype SpecList, as ArrayRef [ PkgSpec | DistSpec ];    ## no critic qw(ProhibitBitwiseOperators);
+subtype TargetList, as ArrayRef [ PackageTarget | DistributionTarget ];    ## no critic qw(ProhibitBitwiseOperators);
 
-coerce SpecList,
-    from PkgSpec, via { [$_] },
-    from DistSpec, via { [$_] }, from Str, via { [ Pinto::SpecFactory->make_spec($_) ] }, from ArrayRef [Str], via {
-    [ map { Pinto::SpecFactory->make_spec($_) } @$_ ];
-    };
+coerce TargetList,
+    from PackageTarget,      via { [ $_ ] },
+    from DistributionTarget, via { [ $_ ] },
+    from Str,                via { [ Pinto::Target->new($_) ] },
+    from ArrayRef[Str],      via { [ map { Pinto::Target->new($_) } @$_ ] };
 
 #-----------------------------------------------------------------------------
 
-subtype DistSpecList, as ArrayRef [DistSpec];            ## no critic qw(ProhibitBitwiseOperators);
+subtype DistributionTargetList, as ArrayRef [DistributionTarget];            ## no critic qw(ProhibitBitwiseOperators);
 
-coerce DistSpecList,
-    from DistSpec, via { [$_] }, from Str, via { [ Pinto::DistributionSpec->new($_) ] }, from ArrayRef [Str], via {
-    [ map { Pinto::DistributionSpec->new($_) } @$_ ];
-    };
+coerce DistributionTargetList,
+    from DistributionTarget,  via { [$_] },
+    from Str,                 via { [ Pinto::Target::Distribution->new($_) ] },
+    from ArrayRef[Str],       via { [ map { Pinto::Target::Distribution->new($_) } @$_ ] };
 
 #-----------------------------------------------------------------------------
 
-subtype PkgSpecList, as ArrayRef [PkgSpec];              ## no critic qw(ProhibitBitwiseOperators);
+subtype PackageTargetList, as ArrayRef [PackageTarget];              ## no critic qw(ProhibitBitwiseOperators);
 
-coerce PkgSpecList,
-    from DistSpec, via { [$_] }, from Str, via { [ Pinto::PackageSpec->new($_) ] }, from ArrayRef [Str], via {
-    [ map { Pinto::PackageSpec->new($_) } @$_ ];
-    };
+coerce PackageTargetList,
+    from DistributionTarget,  via { [ $_ ] },
+    from Str,                 via { [ Pinto::Target::Package->new($_) ] },
+    from ArrayRef[Str],       via { [ map { Pinto::Target::Package->new($_) } @$_ ] };
 
 #-----------------------------------------------------------------------------
 
 subtype Io, as Object;
 
 coerce Io,
-    from Str,  via { my $fh = IO::File->new(); $fh->open($_);   return $fh },
-    from File, via { my $fh = IO::File->new(); $fh->open("$_"); return $fh },
+    from Str,       via { my $fh = IO::File->new(); $fh->open($_);   return $fh },
+    from File,      via { my $fh = IO::File->new(); $fh->open("$_"); return $fh },
     from ArrayRef,  via { IO::Handle->new_from_fd(@$_) },
     from ScalarRef, via { IO::String->new( ${$_} ) };
 
@@ -195,6 +232,10 @@ subtype RevisionHead, as Undef;
 
 #-----------------------------------------------------------------------------
 
+enum DiffStyle, [$PINTO_DIFF_STYLE_CONCISE, $PINTO_DIFF_STYLE_DETAILED];
+
+#-----------------------------------------------------------------------------
+
 1;
 
 __END__
@@ -205,8 +246,8 @@ __END__
 
 =for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
 G. Bergsten-Buret Schwern Oleg Gashev Steffen Schwigon Tommy Stanton
-Wolfgang Kinkeldei Yanick Boris Champoux hesco popl Däppen Cory G Watson
-David Steinbrunner Glenn
+Wolfgang Kinkeldei Yanick Boris Champoux brian d foy hesco popl Däppen Cory
+G Watson David Steinbrunner Glenn
 
 =head1 NAME
 
@@ -214,7 +255,7 @@ Pinto::Types - Moose types used within Pinto
 
 =head1 VERSION
 
-version 0.096
+version 0.098
 
 =head1 AUTHOR
 
